summaryrefslogtreecommitdiffstats
diff options
context:
space:
mode:
-rw-r--r--apps/files_sharing/js/public.js7
1 files changed, 6 insertions, 1 deletions
diff --git a/apps/files_sharing/js/public.js b/apps/files_sharing/js/public.js
index 02ecf56fa09..cbd135028f1 100644
--- a/apps/files_sharing/js/public.js
+++ b/apps/files_sharing/js/public.js
@@ -8,7 +8,7 @@
*
*/
/* global FileActions, Files */
/* global dragOptions, folderDropOptions */
if (!OCA.Sharing) {
OCA.Sharing = {};
@@ -164,6 +164,11 @@ OCA.Sharing.PublicApp = {
// URL history handling
this.fileList.$el.on('changeDirectory', _.bind(this._onDirectoryChanged, this));
OC.Util.History.addOnPopStateHandler(_.bind(this._onUrlChanged, this));
+
+ $('#download').click(function (e) {
+ e.preventDefault();
+ OC.redirect(FileList.getDownloadUrl());
+ });
}
$(document).on('click', '#directLink', function () {
@@ -8,7 +8,7 @@
*
*/
-/* global FileActions, Files */
+/* global FileActions, Files, FileList */
/* global dragOptions, folderDropOptions */
if (!OCA.Sharing) {